==> migrate_wizard-2.0.7-alpha1.tar.gz: migrate_wizard/src/Plugin/migrate/destination/MWEntityFile.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\migrate\destination;

use Drupal\Core\Field\Plugin\Field\FieldType\UriItem;
use Drupal\migrate\Row;
use Drupal\migrate\MigrateException;
use Drupal\migrate\Plugin\migrate\destination\EntityContentBase;

/**
 * @MigrateDestination(
 *   id = "mwentity:file"
 * )
 */
class MWEntityFile extends EntityContentBase {

  /**
   * {@inheritdoc}
   */
  public function getEntity(Row $row, array $old_destination_id_values) {
    // For stub rows, there is no real file to deal with, let the stubbing
    // process take its default path.
    if ($row->isStub()) {
      return parent::getEntity($row, $old_destination_id_values);
    }

    // By default the entity key (fid) would be used, but we want to make sure
    // we're loading the matching URI.
    $destination = $row->getSourceProperty('uri');
    if (empty($destination)) {
      throw new MigrateException('Destination property uri not provided');
    }
    $entity = $this->storage->loadByProperties(['uri' => $destination]);
    if ($entity) {
      return reset($entity);
    }
    else {
      $entity_id = reset($old_destination_id_values) ?: $this->getEntityId($row);
      if (!empty($entity_id) && ($entity = $this->storage->load($entity_id))) {
        // Allow updateEntity() to change the entity.
        $entity = $this->updateEntity($entity, $row) ?: $entity;
      }
      else {
        // Attempt to ensure we always have a bundle.
        if ($bundle = $this->getBundle($row)) {
          $row->setDestinationProperty($this->getKey('bundle'), $bundle);
        }

        // Stubs might need some required fields filled in.
        if ($row->isStub()) {
          $this->processStubRow($row);
        }
        $destination = [
          'filename' => $row->getSourceProperty('filename'),
          'source_full_path' => $row->getSourceProperty('source_base_path').'/'.$row->getSourceProperty('filepath'),
          'uri' => $row->getSourceProperty('uri'),
          'filemime' => $row->getSourceProperty('filemime'),
          'status' => $row->getSourceProperty('status'),
          'created' => $row->getSourceProperty('timestamp'),
          'change' => $row->getSourceProperty('timestamp'),
          'uid' => $row->getSourceProperty('uid'),
        ];
        $entity = $this->storage->create($destination);
        $entity->enforceIsNew();
        return $entity;
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function processStubRow(Row $row) {
    // We stub the uri value ourselves so we can create a real stub file for it.
    if (!$row->getDestinationProperty('uri')) {
      $field_definitions = $this->entityFieldManager
        ->getFieldDefinitions($this->storage->getEntityTypeId(),
          $this->getKey('bundle'));
      $value = UriItem::generateSampleValue($field_definitions['uri']);
      if (empty($value)) {
        throw new MigrateException('Stubbing failed, unable to generate value for field uri');
      }
      // generateSampleValue() wraps the value in an array.
      $value = reset($value);
      // Make it into a proper public file uri, stripping off the existing
      // scheme if present.
      $value = 'public://' . preg_replace('|^[a-z]+://|i', '', $value);
      $value = mb_substr($value, 0, $field_definitions['uri']->getSetting('max_length'));
      // Create a real file, so File::preSave() can do filesize() on it.
      touch($value);
      $row->setDestinationProperty('uri', $value);
    }
    parent::processStubRow($row);
  }

}

==> migrate_wizard-2.0.8-alpha1.tar.gz: migrate_wizard/src/Plugin/migrate/destination/MWEntityFile.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\migrate\destination;

use Drupal\Core\Field\Plugin\Field\FieldType\UriItem;
use Drupal\migrate\Row;
use Drupal\migrate\MigrateException;
use Drupal\migrate\Plugin\migrate\destination\EntityContentBase;

/**
 * @MigrateDestination(
 *   id = "mwentity:file"
 * )
 */
class MWEntityFile extends EntityContentBase {

  /**
   * {@inheritdoc}
   */
  public function getEntity(Row $row, array $old_destination_id_values) {
    // For stub rows, there is no real file to deal with, let the stubbing
    // process take its default path.
    if ($row->isStub()) {
      return parent::getEntity($row, $old_destination_id_values);
    }

    // By default the entity key (fid) would be used, but we want to make sure
    // we're loading the matching URI.
    $destination = $row->getSourceProperty('uri');
    if (empty($destination)) {
      throw new MigrateException('Destination property uri not provided');
    }
    $entity = $this->storage->loadByProperties(['uri' => $destination]);
    if ($entity) {
      $entity = reset($entity);
    }
    else {
      $entity_id = reset($old_destination_id_values) ?: $this->getEntityId($row);
      if (!empty($entity_id) && ($entity = $this->storage->load($entity_id))) {
        // Allow updateEntity() to change the entity.
        $entity = $this->updateEntity($entity, $row) ?: $entity;
      }
      else {
        // Attempt to ensure we always have a bundle.
        if ($bundle = $this->getBundle($row)) {
          $row->setDestinationProperty($this->getKey('bundle'), $bundle);
        }

        // Stubs might need some required fields filled in.
        if ($row->isStub()) {
          $this->processStubRow($row);
        }
        $destination = [
          'filename' => $row->getSourceProperty('filename'),
          'source_full_path' => $row->getSourceProperty('source_base_path').'/'.$row->getSourceProperty('filepath'),
          'uri' => $row->getSourceProperty('uri'),
          'filemime' => $row->getSourceProperty('filemime'),
          'status' => $row->getSourceProperty('status'),
          'created' => $row->getSourceProperty('timestamp'),
          'change' => $row->getSourceProperty('timestamp'),
          'uid' => $row->getSourceProperty('uid'),
        ];
        $entity = $this->storage->create($destination);
        $entity->enforceIsNew();
      }
    }
    return $entity;
  }

  /**
   * {@inheritdoc}
   */
  protected function processStubRow(Row $row) {
    // We stub the uri value ourselves so we can create a real stub file for it.
    if (!$row->getDestinationProperty('uri')) {
      $field_definitions = $this->entityFieldManager
        ->getFieldDefinitions($this->storage->getEntityTypeId(),
          $this->getKey('bundle'));
      $value = UriItem::generateSampleValue($field_definitions['uri']);
      if (empty($value)) {
        throw new MigrateException('Stubbing failed, unable to generate value for field uri');
      }
      // generateSampleValue() wraps the value in an array.
      $value = reset($value);
      // Make it into a proper public file uri, stripping off the existing
      // scheme if present.
      $value = 'public://' . preg_replace('|^[a-z]+://|i', '', $value);
      $value = mb_substr($value, 0, $field_definitions['uri']->getSetting('max_length'));
      // Create a real file, so File::preSave() can do filesize() on it.
      touch($value);
      $row->setDestinationProperty('uri', $value);
    }
    parent::processStubRow($row);
  }

}
